BorderedRectangle

Struct BorderedRectangle 

pub struct BorderedRectangle {
    pub common: CommonBuilder,
    pub style: Style,
}
A filled rectangle widget that may or may not have some border.

Fields

common: CommonBuilder

Data necessary and common for all widget builder types.

style: Style

Unique styling for the BorderedRectangle.

Implementations

Source

impl BorderedRectangle

pub fn new(dim: [f64; 2]) -> BorderedRectangle

Build a new BorderedRectangle.

pub fn with_style(self, with_style: Style) -> BorderedRectangle

Build the type’s self.$($assignee).+ with the given $Type.