pub enum ScrollbarPosition {
NextTo,
OnTop,
}Expand description
If the List is scrollable, this describes how th Scrollbar should be positioned.
Variants
NextTo
To the right of the items (reduces the item width to fit).
OnTop
On top of the right edge of the items with auto_hide activated.