DropDownList

Struct DropDownList 

pub struct DropDownList<'a, T>
where T: 'a,
{ /* private fields */ }
Displays a given Vec<String> as a selectable drop down menu.

It’s reaction is triggered upon selection of a list item.

Implementations

Source

impl<'a, T> DropDownList<'a, T>

pub fn new(items: &'a [T], selected: Option<usize>) -> DropDownList<'a, T>

Construct a new DropDownList.

pub fn enabled(self, enabled: bool) -> DropDownList<'a, T>

Build the type’s self.$($assignee).+ with the given $Type.

pub fn max_visible_items(self, num: usize) -> DropDownList<'a, T>

Set the maximum height of the DropDownList (before the scrollbar appears) as a number of items.

pub fn max_visible_height(self, height: f64) -> DropDownList<'a, T>

Set the maximum height of the DropDownList (before the scrollbar appears) as a scalar height.

pub fn scrollbar_next_to(self) -> DropDownList<'a, T>

Specifies that the list should be scrollable and should provide a Scrollbar to the right of the items.

pub fn scrollbar_on_top(self) -> DropDownList<'a, T>

Specifies that the list should be scrollable and should provide a Scrollbar that hovers above the right edge of the items and automatically hides when the user is not scrolling.

pub fn no_scrollbar(self) -> DropDownList<'a, T>

Even in the case that the list is scrollable, do not display a Scrollbar.

pub fn scrollbar_width(self, w: f64) -> DropDownList<'a, T>

Specify the width of the scrollbar.

pub fn label_font_id(self, font_id: Id) -> DropDownList<'a, T>

Specify the font used for displaying the label.

pub fn left_justify_label(self) -> DropDownList<'a, T>

Align the labels to the left of their Buttons’ surface.

pub fn right_justify_label(self) -> DropDownList<'a, T>

Align the labels to the right of their Buttons’ surface.

pub fn center_justify_label(self) -> DropDownList<'a, T>

Center the labels to the their Buttons’ surface.

pub fn label_x(self, x: Relative) -> DropDownList<'a, T>

Specify the label’s position relatively to Button along the x axis.

pub fn label_y(self, y: Relative) -> DropDownList<'a, T>

Specify the label’s position relatively to Button along the y axis.