pub struct FileNavigator<'a> {
pub style: Style,
pub starting_directory: &'a Path,
pub types: Types<'a>,
/* private fields */
}Expand description
A widget for navigating and interacting with a file system.
Fields
style: StyleUnique styling for the widget.
starting_directory: &'a PathThe first directory shown for the FileNavigator.
types: Types<'a>Only display files of the given type.
Implementations
Sourcepub fn new(starting_directory: &'a Path, types: Types<'a>) -> FileNavigator<'a>
pub fn new(starting_directory: &'a Path, types: Types<'a>) -> FileNavigator<'a>
Begin building a FileNavigator widget that displays only files of the given types.
Sourcepub fn all(starting_directory: &'a Path) -> FileNavigator<'a>
pub fn all(starting_directory: &'a Path) -> FileNavigator<'a>
Begin building a FileNavigator that will display all file types.
Sourcepub fn with_extension(
starting_directory: &'a Path,
exts: &'a [&'a str],
) -> FileNavigator<'a>
pub fn with_extension( starting_directory: &'a Path, exts: &'a [&'a str], ) -> FileNavigator<'a>
Begin building a FileNavigator that will only display files whose extensions match one
of those within the given extension list.
i.e. A FileNavigator used for navigating lossless audio files might use the following
list of extensions: &["wav", "wave", "aiff"].
Sourcepub fn directories(starting_directory: &'a Path) -> FileNavigator<'a>
pub fn directories(starting_directory: &'a Path) -> FileNavigator<'a>
Begin building a FileNavigator that only displays directories.
Sourcepub fn unselected_color(self, color: Color) -> FileNavigator<'a>
pub fn unselected_color(self, color: Color) -> FileNavigator<'a>
The color of the unselected entries within each DirectoryView.
Sourcepub fn text_color(self, color: Color) -> FileNavigator<'a>
pub fn text_color(self, color: Color) -> FileNavigator<'a>
The color of the Text used to display the file names.
Whether to show hidden files and directories.
Sourcepub fn font_size(self, font_size: u32) -> FileNavigator<'a>
pub fn font_size(self, font_size: u32) -> FileNavigator<'a>
Build the type’s self.$($assignee).+ with the given $Type.