pub struct Graph<'a, N, E>where
N: Iterator,
<N as Iterator>::Item: NodeId,
E: Iterator<Item = (NodeSocket<<N as Iterator>::Item>, NodeSocket<<N as Iterator>::Item>)>,{
pub common: CommonBuilder,
pub style: Style,
pub nodes: N,
pub edges: E,
pub layout: &'a Layout<<N as Iterator>::Item>,
}Expand description
A widget used for visualising and manipulating Graph types.
Fields
common: CommonBuilderData necessary and common for all widget builder types.
style: StyleUnique styling for the Graph.
nodes: NAll nodes within the graph that the widget is to represent.
edges: EAll edges within the graph.
layout: &'a Layout<<N as Iterator>::Item>The position of each node within the graph.
Implementations
Sourceimpl<'a, N, E> Graph<'a, N, E>
impl<'a, N, E> Graph<'a, N, E>
Sourcepub fn new<NI, EI>(
nodes: NI,
edges: EI,
layout: &'a Layout<<NI as IntoIterator>::Item>,
) -> Graph<'a, N, E>where
NI: IntoIterator<IntoIter = N, Item = <N as Iterator>::Item>,
EI: IntoIterator<IntoIter = E, Item = (NodeSocket<<N as Iterator>::Item>, NodeSocket<<N as Iterator>::Item>)>,
pub fn new<NI, EI>(
nodes: NI,
edges: EI,
layout: &'a Layout<<NI as IntoIterator>::Item>,
) -> Graph<'a, N, E>where
NI: IntoIterator<IntoIter = N, Item = <N as Iterator>::Item>,
EI: IntoIterator<IntoIter = E, Item = (NodeSocket<<N as Iterator>::Item>, NodeSocket<<N as Iterator>::Item>)>,
Begin building a new Graph widget.
Sourcepub fn background_color(self, color: Color) -> Graph<'a, N, E>
pub fn background_color(self, color: Color) -> Graph<'a, N, E>
Color the Graph’s rectangular area with the given color.