PreUpdateCache

Struct PreUpdateCache 

pub struct PreUpdateCache {
Show 15 fields pub type_id: TypeId, pub id: NodeIndex, pub maybe_parent_id: Option<NodeIndex>, pub maybe_x_positioned_relatively_id: Option<NodeIndex>, pub maybe_y_positioned_relatively_id: Option<NodeIndex>, pub rect: Rect, pub depth: f32, pub kid_area: KidArea, pub maybe_dragged_from: Option<[f64; 2]>, pub maybe_floating: Option<Floating>, pub crop_kids: bool, pub maybe_x_scroll_state: Option<State<X>>, pub maybe_y_scroll_state: Option<State<Y>>, pub maybe_graphics_for: Option<NodeIndex>, pub is_over: fn(&Container, [f64; 2], &Theme) -> IsOver,
}

Fields

type_id: TypeId

The Widget’s unique type identifier.

id: NodeIndex

The Widget’s unique Id.

maybe_parent_id: Option<NodeIndex>

The Widget’s parent’s unique index (if it has a parent).

maybe_x_positioned_relatively_id: Option<NodeIndex>

If this Widget is relatively positioned to another Widget, this will be the index of the Widget to which this Widget is relatively positioned along the x axis.

maybe_y_positioned_relatively_id: Option<NodeIndex>

If this Widget is relatively positioned to another Widget, this will be the index of the Widget to which this Widget is relatively positioned along the y axis.

rect: Rect

The Rect describing the Widget’s position and dimensions.

depth: f32

The z-axis depth - affects the render order of sibling widgets.

kid_area: KidArea

The area upon which the Widget’s children widgets will be placed.

maybe_dragged_from: Option<[f64; 2]>

If Widget is draggable and is being dragged, this is where it started

maybe_floating: Option<Floating>

Floating data for the Widget if there is some.

crop_kids: bool

Whether or not the children of the Widget should be cropped to its kid_area.

maybe_x_scroll_state: Option<State<X>>

Scrolling data for the Widget’s x axis if there is some.

maybe_y_scroll_state: Option<State<Y>>

Scrolling data for the Widget’s y axis if there is some.

maybe_graphics_for: Option<NodeIndex>

Whether or not the Widget has been instantiated as a graphical element for some other widget.

is_over: fn(&Container, [f64; 2], &Theme) -> IsOver

A function describing whether or not a given point is over the widget.