pub struct DropDownList<'a, T>where
T: 'a,{ /* private fields */ }Expand description
Displays a given Vec<String> as a selectable drop down menu.
It’s reaction is triggered upon selection of a list item.
Implementations
Sourceimpl<'a, T> DropDownList<'a, T>
impl<'a, T> DropDownList<'a, T>
Sourcepub fn new(items: &'a [T], selected: Option<usize>) -> DropDownList<'a, T>
pub fn new(items: &'a [T], selected: Option<usize>) -> DropDownList<'a, T>
Construct a new DropDownList.
Sourcepub fn enabled(self, enabled: bool) -> DropDownList<'a, T>
pub fn enabled(self, enabled: bool) -> DropDownList<'a, T>
Build the type’s self.$($assignee).+ with the given $Type.
Sourcepub fn max_visible_items(self, num: usize) -> DropDownList<'a, T>
pub fn max_visible_items(self, num: usize) -> DropDownList<'a, T>
Set the maximum height of the DropDownList (before the scrollbar appears) as a number of items.
Sourcepub fn max_visible_height(self, height: f64) -> DropDownList<'a, T>
pub fn max_visible_height(self, height: f64) -> DropDownList<'a, T>
Set the maximum height of the DropDownList (before the scrollbar appears) as a scalar height.
Sourcepub fn scrollbar_next_to(self) -> DropDownList<'a, T>
pub fn scrollbar_next_to(self) -> DropDownList<'a, T>
Specifies that the list should be scrollable and should provide a Scrollbar to the right
of the items.
Sourcepub fn scrollbar_on_top(self) -> DropDownList<'a, T>
pub fn scrollbar_on_top(self) -> DropDownList<'a, T>
Specifies that the list should be scrollable and should provide a Scrollbar that hovers
above the right edge of the items and automatically hides when the user is not scrolling.
Sourcepub fn no_scrollbar(self) -> DropDownList<'a, T>
pub fn no_scrollbar(self) -> DropDownList<'a, T>
Even in the case that the list is scrollable, do not display a Scrollbar.
Sourcepub fn scrollbar_width(self, w: f64) -> DropDownList<'a, T>
pub fn scrollbar_width(self, w: f64) -> DropDownList<'a, T>
Specify the width of the scrollbar.
Sourcepub fn label_font_id(self, font_id: Id) -> DropDownList<'a, T>
pub fn label_font_id(self, font_id: Id) -> DropDownList<'a, T>
Specify the font used for displaying the label.
Sourcepub fn left_justify_label(self) -> DropDownList<'a, T>
pub fn left_justify_label(self) -> DropDownList<'a, T>
Align the labels to the left of their Buttons’ surface.
Sourcepub fn right_justify_label(self) -> DropDownList<'a, T>
pub fn right_justify_label(self) -> DropDownList<'a, T>
Align the labels to the right of their Buttons’ surface.
Sourcepub fn center_justify_label(self) -> DropDownList<'a, T>
pub fn center_justify_label(self) -> DropDownList<'a, T>
Center the labels to the their Buttons’ surface.
Sourcepub fn label_x(self, x: Relative) -> DropDownList<'a, T>
pub fn label_x(self, x: Relative) -> DropDownList<'a, T>
Specify the label’s position relatively to Button along the x axis.
Sourcepub fn label_y(self, y: Relative) -> DropDownList<'a, T>
pub fn label_y(self, y: Relative) -> DropDownList<'a, T>
Specify the label’s position relatively to Button along the y axis.